@@ -3,7 +3,7 @@
 ;; Copyright (C) 1999-2020 Free Software Foundation, Inc. and Ken Manheimer
 
 ;; Author: Ken Manheimer <ken.manheimer@gmail.com>
-;; Version: 1.1.7
+;; Version: 1.1.8
 ;; Created: 1999 -- first public availability
 ;; Keywords: processes
 ;; Package-Requires: ((cl-lib "0.5"))
@@ -60,6 +60,11 @@
 ;;
 ;; Change Log:
 ;;
+;; * 2020-10-28 1.1.8 Ken Manheimer:
+;;   - Change back to having multishell-list require multishell,
+;;     rather than the other way around, and remove now unnecessary
+;;     new autoloads.
+;;   - Bump version for ELPA release.
 ;; * 2020-10-28 1.1.7 Ken Manheimer:
 ;;   - Forward compatibility: 'cl-progv' rather than 'progv', resolves
 ;;     multishell-list error in recent emacs versions.
@@ -165,9 +170,8 @@
 (require 'comint)
 (require 'shell)
 (require 'savehist)
-(require 'multishell-list)
 
-(defvar multishell-version "1.1.7")
+(defvar multishell-version "1.1.8")
 (defun multishell-version (&optional here)
   "Return string describing the loaded multishell version."
   (interactive "P")
@@ -304,7 +308,6 @@ Returns non-nil iff any changes were made."
             did-revisions t))
     did-revisions))
 
-;;;###autoload
 (defun multishell-history-entries (name)
   "Return `multishell-history' entry that starts with NAME, or nil if none."
   (let (got)
@@ -827,7 +830,6 @@ Returns nil for empty parts, rather than the empty string."
   (if (not (string= (substring name -1) "*"))
       (setq name (concat name "*")))
   name)
-;;;###autoload
 (defun multishell-unbracket (name)
   "Return a copy of name, removing asterisks, if any, at beginning and end."
   (if (string= (substring name 0 1) "*")
